Extracts the list of available countries from the Google Charts documentation
gchart_countries(
server = "https://developers.google.com/chart/interactive/docs/gallery/geochart",
cache = gchart_get_cache_path(),
format = c("rds", "rda"),
update = FALSE,
verbose = TRUE
)A data.frame with information for all countries available in
the service.
Location for the relevant Google Charts documentation. Use the default.
Path to store downloaded data.
Which format to use for storing the countries table.
Whether to update the table even if it is cached.
Whether to show messages during processing.
Extracts the information of countries available in the Google Charts geochart service from the online documentation