Access the Google Charts geochart data for countries
gchart_get_countries(
countries = "all",
server = "https://www.gstatic.com/charts/geochart/10/mapfiles/",
cache = gchart_get_cache_path(),
verbose = FALSE
)Country codes to get.
Google geochart server to access.
Path to store downloaded data.
Whether to show messages during processing.
The function invisibly returns the file path for successful requests or the response status code for failed requests, in a character vector with the country code for each element.