Access the Google Charts geochart data for US areas
gchart_get_us_areas(
areas,
server = "https://www.gstatic.com/charts/geochart/10/mapfiles/",
cache = gchart_get_cache_path(),
limit = 1000
)Area codes to get. Should be integers.
Google geochart server to access.
Path to store downloaded data.
Maximum number of areas to look for
The function invisibly returns the file path for successful requests or the response status code for failed requests, in a character vector with the area name for each element.